aboutsummaryrefslogtreecommitdiffstats
path: root/tests/phpunit/unit/includes/PathRouterTest.php
diff options
context:
space:
mode:
Diffstat (limited to 'tests/phpunit/unit/includes/PathRouterTest.php')
-rw-r--r--tests/phpunit/unit/includes/PathRouterTest.php4
1 files changed, 3 insertions, 1 deletions
diff --git a/tests/phpunit/unit/includes/PathRouterTest.php b/tests/phpunit/unit/includes/PathRouterTest.php
index bdf9fd668a26..86a6d68fc28e 100644
--- a/tests/phpunit/unit/includes/PathRouterTest.php
+++ b/tests/phpunit/unit/includes/PathRouterTest.php
@@ -1,7 +1,9 @@
<?php
+use MediaWiki\Request\PathRouter;
+
/**
* Tests for the PathRouter parsing.
*
* @covers PathRouter
*/
@@ -1,7 +1,9 @@
/**
- * Tests for the PathRouter parsing.
+ * Tests for the MediaWiki\Request\PathRouter parsing.
*
* @covers PathRouter